- BD_Obs
A data.table or data.frame containing observational data with the following structure:
The first column (Date): A Date object representing the observation date.
The remaining columns: Each column corresponds to a unique ground station, where the column name is the station identifier.
The dataset should be structured as follows:
> BD_Obs
# A data.table or data.frame with n rows (dates) and m+1 columns (stations + Date)
Date ST001 ST002 ST003 ST004 ...
<date> <dbl> <dbl> <dbl> <dbl> ...
1 2015-01-01 0 0 0 0 ...
2 2015-01-02 0 0 0 0.2 ...
3 2015-01-03 0.1 0 0 0.1 ...
Each station column contains numeric values representing observed measurements.
The column names (station identifiers) must be unique and match those in BD_Coord$Cod to ensure proper spatial referencing.
- BD_Coord
A data.table or data.frame containing the metadata of the ground stations. It must include the following columns:
"Cod":
Unique identifier for each ground station.
"X":
Latitude of the station in UTM format.
"Y":
Longitude of the station in UTM format.
- shapefile
A shapefile defining the study area, used to constrain the interpolation to the region of interest.
The shapefile must be of class SpatVector (from the terra package) and should have a UTM coordinate reference system.
- grid_resolution
A numeric value indicating the resolution of the interpolation grid in kilometers (km).
- search_radius
A numeric vector indicating the search radius in kilometers (km) for the Cressman method.
Note: See the "Notes" section for additional details on how to search radius values.
- training
Numerical value between 0 and 1 indicating the proportion of data used for model training. The remaining data are used for validation. Note that if you enter, for example, 0.8 it means that 80 % of the data will be used for training and 20 % for validation.
If you do not want to perform validation, set training = 1. (Default training = 1).
- stat_validation
A character vector specifying the names of the stations to be used for validation.
This option should only be filled in when it is desired to manually enter the stations used for validation. If this parameter is NULL, and the formation is different from 1, a validation will be performed using random stations.
The vector must contain the names of the stations selected by the user for validation.
For example, stat_validation = c(“ST001”, “ST002”). (Default stat_validation = NULL).
- Rain_threshold
List of numerical vectors defining precipitation thresholds to classify precipitation into different categories according to its intensity.
This parameter should be entered only when the validation is to include categorical metrics such as Critical Success Index (CSI), Probability of Detection (POD), False Alarm Rate (FAR), etc.
Each list item should represent a category, with the category name as the list item name and a numeric vector specifying the lower and upper bounds of that category.
Note: See the "Notes" section for additional details on how to define categories, use this parameter for validation, and example configurations.
- save_model
Logical value indicating whether the interpolation file should be saved to disk. The default value is FALSE. indicating that the interpolated file should not be saved.